/**
 * 千分位格式化
 * @param num 100000
 * @returns 100,100
 */
function Thousands(num: number): string {
  if (String(num).length <= 3) return num + "";
  let reg = /\d{1,3}(?=(\d{3})+$)/g;
  return (num + '').replace(reg, '$&,');
}

/**
 * 小数位补零
 * @param num
 * @returns 0.00
 */
function Decimal_zeroFilling(num: number | string): string {
  if (!num) return "00";
  num = String(num);
  if (num == '0') return "00";
  if (num.length < 2) return num.padEnd(2, '0');
  return num.slice(0, 2);
}

/**
 * 格式化数字
 * 例：FormatMoney(5000,2)  =>5,000.00
 * @param num :5000
 * @param decimal :2 (小数位)
 * @returns  5,000.00
 */
function FormatMoney(num: number, decimal?: number) {
  if (!num) {
    return "0.00";
  }
  let isFilter = false;
  let sStr = "";
  if (decimal) {
    decimal = decimal > 0 && decimal <= 20 ? decimal : 2;
    sStr = `${parseFloat(String(num).replace(/[^\d.-]/g, "")).toFixed(decimal)}`;
  } else {
    num = parseInt(String(num).replace(/[^\d.-]/g, ""));
  }

  const l = sStr.split(".")[0].split("").reverse();
  const r = sStr.split(".")[1];
  let t = "";
  /*  过滤负数 -号 */
  if (l.indexOf("-") !== -1) {
    l.splice(l.indexOf("-"), 1);
    isFilter = true;
  }
  /* end */
  for (let i = 0; i < l.length; i++) {
    t += l[i] + ((i + 1) % 3 == 0 && i + 1 != l.length ? "," : "");
  }
  if (!isFilter) {
    return `${t.split("").reverse().join("")}.${r}`;
  } else {
    return `-${t.split("").reverse().join("")}.${r}`;
  }
}

/**
 * 
 * @param value 
 * @param baseUnit 
 * @param NaNText 
 * @returns 
 */
function MoneyUnitSwitch(value: number, baseUnit: number, NaNText) {
  if (isNaN(value)) {
    return NaNText || 0;
  }
  baseUnit = baseUnit || 10000;
  let num = (value / baseUnit).toFixed(2);
  const numStr = num.toString();

  // 千分位符
  const integer = numStr.split('.')[0];
  const decimal = numStr.split('.').length > 1 ? `.${numStr.split('.')[1]}` : '';
  const strArr = `${integer}`
    .split('')
    .reverse()
    .join('')
    .replace(/(\d{3})(?=\d)/g, '$1,')
    .split('')
    .reverse();
  return strArr.join('') + decimal;
}


/**
 * num为传入的值，n为保留的小数位 n 默认保留2位小数
 * @param num
 * @param decimal 小数位 （ 默认值：2）
 * @returns
 */
function FormatFloat(num: number, decimal?: number) {
  let f = parseFloat(String(num));
  if (isNaN(f)) {
    return 0;
  }
  decimal = decimal || 2;
  f = Math.round(num * Math.pow(10, decimal)) / Math.pow(10, decimal); // n 幂
  let s = f.toString();
  let rs = s.indexOf('.');
  // 判定如果是整数，增加小数点再补0
  if (rs < 0) {
    rs = s.length;
    s += '.';
  }
  while (s.length <= rs + decimal) {
    s += '0';
  }
  return s;
}


/**
 * 只能输入数字和小数点；
 * 小数点只能有1个
 * 第一位不能是小数点 也不能是 0
 * 小数点后保留2位
 * @param num
 * @returns
 */
function NumberCheck(num: string | number) {
  let str = num.toString();
  const len1 = str.substr(0, 1);
  const len2 = str.substr(1, 1);
  // 如果第一位是0，第二位不是点，就用数字把点替换掉
  if (str.length > 1 && len1 == String(0) && len2 != '.') {
    str = str.substr(1, 1);
  }
  // 第一位不能是.
  if (len1 == '.') {
    str = '';
  }
  // 限制只能输入一个小数点
  if (str.indexOf('.') != -1) {
    const str_ = str.substr(str.indexOf('.') + 1);
    if (str_.indexOf('.') != -1) {
      str = str.substr(0, str.indexOf('.') + str_.indexOf('.') + 1);
    }
  }
  // 正则替换，保留数字和小数点
  str = str.replace(/[^\d.]/g, '');
  // 如果需要保留小数点后两位，则用下面公式
  str = str.replace(/\.\d\d\d$/, '');
  /* 特殊处理 */
  // if (str) {
  //   return +str;
  // }else{
  //   return null;
  // }
  /* end */
  /* 正常处理 */
  return str;
}

/**
 * 只能输入整数 第一位不能为0
 * @param num
 * @returns
 */
function FilterNum(num: string) {
  let str = num.replace(/[^\d]/g, '');
  str = str.toString();
  if (str.substr(0, 1) == String(0)) {
    return '';
  }
  return str;
}

/**
 * 只能输入整数
 * @param {string} num
 * @returns
 */
function FilterNumber(num: string) {
  let str = num.replace(/[^\d]/g, '');
  str = str.toString();
  return str;
}


export {
  Thousands,
  Decimal_zeroFilling,
  FormatMoney,
  MoneyUnitSwitch,
  FormatFloat,
  NumberCheck,
  FilterNum,
  FilterNumber
}