/**
 * 树数据过滤
 * @param tree 树数据
 * @param childKey 子数据key
 * @param filterKey 需要筛选的key
 * @param value 需要筛选的值
 * @returns []
 */
function FilterTreeNode(tree, childKey, filterKey, value) {
  let newArr = <any>[];
  for (let item of tree) {
    if (item[childKey] && item[childKey].length) {
      item[childKey] = filterTreeNode(
        item[childKey],
        childKey,
        filterKey,
        value
      );
    }

    let res = item[filterKey];
    if (res === value) {
      newArr.push(item);
    }
  }
  return newArr;
};

/**
 * 防抖函数
 * @param {Function} func 传入方法
 * @param {number} delay 延迟时间
 */
function Debounce(func: Function, delay: number) {
  let timer;
  return function (...args) {
    if (timer) {
      clearTimeout(timer);
    }
    timer = setTimeout(() => {
      func.apply(this, args);
    }, delay);
  };
};

/**
 * 节流函数
 * @param {Function} func 执行方法
 * @param {number} wait 等待时间
 * @returns 
 */
function Throttle(func: Function, wait: number) {
  var timer = <number>0;
  return function () {
    var context = this;
    var args = arguments;
    if (!timer) {
      timer = setTimeout(function () {
        func.apply(context, args);
        timer = 0;
      }, wait);
    }
  };
}

// 限制输入逗号
function StrIpScript(value: string) {
  return value.replace(",", "");
}


/**
 *  权限对比
 *  @param  matchArr
 *  @param  userArr
 *  @returns  {boolean}
 */
function AuthorityComparison(matchArr, userArr) {
  if (!userArr) {
    // 如果没有设置权限码，默认不需要
    return true;
  }
  let temp = false;
  matchArr = matchArr || [];
  if (typeof userArr === "string" || typeof userArr === "number") {
    return matchArr.includes(userArr);
  } else {
    userArr.forEach((item) => {
      temp = temp || matchArr.includes(item);
    });
  }
  return temp;
}

/**
 * 添加iframe到文档中
 * @param url
 */
function AddIframeDom(url) {
  let iframe;
  try {
    // IE6, IE7
    iframe = document.createElement('<iframe name="check_oa_login">');
  } catch (e) {
    iframe = document.createElement("iframe");
    iframe.name = "oa_login";
  }
  iframe.src = url;
  iframe.style.width = "0";
  iframe.style.height = "0";
  iframe.style.position = "absolute";
  iframe.style.top = "-9999px";
  iframe.style.left = "-9999px";
  iframe.style.visibility = "hidden";
  document.body.appendChild(iframe);
}

/**
 * 打印图片
 * @param url 
 */
function PrintImage(url) {
  let image = new Image();
  image.style.width = '100%';
  image.style.height = '100%';
  image.style.zIndex = '100000';
  image.style.position = 'fixed';
  image.style.top = '0';
  image.style.left = '0';
  image.src = url;
  let app: Element = document.querySelector('#app')!;
  image.onload = function () {
    app.style.opacity = 0;
    document.body.appendChild(image);

    requestAnimationFrame(() => {
      window.print();
      app.style.opacity = 1;
      document.body.removeChild(image);
    });
  };
}


function Validator_1() {
  console.log('我是。。。Validator。方法');
}

const Validator_2 = () => {
  console.log('我是。。。Validator。方法');
}

export {
  FilterTreeNode,
  Debounce,
  Throttle,
  StrIpScript,
  AuthorityComparison,
  AddIframeDom,
  PrintImage,
  Validator_1,
  Validator_2,
}